# JSON Loggly

A [node.js](http://nodejs.org) module for [Loggly](http://loggly.com),
espcially optimized for node.js API servers that deal in JSON requests
and responses and uses [connect](http://www.senchalabs.org/connect/) for
middleware management.

When calling `res.end()`, the json-loggly module will automatically log
the request to Loggly and stdout.

json-loggly can also log custom log messages and support 4 different log
levels: *debug, info, warning and error.*

## Usage

json-loggly is very simple to use. To log requests, simply:

```js
var connect = require('connect');
var loggly = require('json-loggly').init('your-loggly-api-key');

var app = function (req, res) {
  // Do your stuff here

  req.loggly.logBody(input);  // if PUT or POST request with a json body, log it
  res.loggly.logBody(result); // if response contains json body, log it
  res.end(JSON.stringify(result));
};

connect()
  .use(loggly.middleware()) // inject json-loggly middleware early
  .use(app)                 // Your normal app request handling
  .listen(8080);
```

To log a custom log message use the json-loggly methods `dbg`, `inf`,
`war` or `err`:

```js
var loggly = require('json-loggly').init('your-loggly-api-key');

// Provide a custom object to be logged
loggly.inf({
  service : 'sendgrid',
  msg     : 'Sending welcome e-mail to newly created user',
  to      : { id: user._id, email: user.email }
});

// Or just log a string
loggly.err("Something bad happened");
```

## License

MIT
